@@ -1,10 +1,21 @@
 import _ from 'lodash';
 import { isVersionGtOrEq } from 'app/core/utils/version';
-import { InterpolateFunction } from '@grafana/ui';
+import { InterpolateFunction } from '@grafana/data';
 
-const index = {};
+const index: any = {};
 
-function addFuncDef(funcDef) {
+export interface FuncDef {
+  name: any;
+  category?: string;
+  params?: any;
+  defaultParams?: any;
+  shortName?: any;
+  fake?: boolean;
+  version?: string;
+  description?: string;
+}
+
+function addFuncDef(funcDef: FuncDef) {
   funcDef.params = funcDef.params || [];
   funcDef.defaultParams = funcDef.defaultParams || [];
 
@@ -941,7 +952,7 @@ addFuncDef({
   version: '1.1',
 });
 
-function isVersionRelatedFunction(obj, graphiteVersion) {
+function isVersionRelatedFunction(obj: { version: string }, graphiteVersion: string) {
   return !obj.version || isVersionGtOrEq(graphiteVersion, obj.version);
 }
 
@@ -951,7 +962,7 @@ export class FuncInstance {
   text: any;
   added: boolean;
 
-  constructor(funcDef, options) {
+  constructor(funcDef: any, options: { withDefaultParams: any }) {
     this.def = funcDef;
     this.params = [];
 
@@ -1002,7 +1013,7 @@ export class FuncInstance {
     return str + parameters.join(', ') + ')';
   }
 
-  _hasMultipleParamsInString(strValue, index) {
+  _hasMultipleParamsInString(strValue: any, index: number) {
     if (strValue.indexOf(',') === -1) {
       return false;
     }
@@ -1018,7 +1029,7 @@ export class FuncInstance {
     return false;
   }
 
-  updateParam(strValue, index) {
+  updateParam(strValue: any, index: any) {
     // handle optional parameters
     // if string contains ',' and next param is optional, split and update both
     if (this._hasMultipleParamsInString(strValue, index)) {
@@ -1050,22 +1061,22 @@ export class FuncInstance {
   }
 }
 
-function createFuncInstance(funcDef, options?, idx?) {
+function createFuncInstance(funcDef: any, options?: { withDefaultParams: any }, idx?: any) {
   if (_.isString(funcDef)) {
     funcDef = getFuncDef(funcDef, idx);
   }
   return new FuncInstance(funcDef, options);
 }
 
-function getFuncDef(name, idx?) {
+function getFuncDef(name: string, idx?: any) {
   if (!(idx || index)[name]) {
     throw { message: 'Method not found ' + name };
   }
   return (idx || index)[name];
 }
 
-function getFuncDefs(graphiteVersion, idx?) {
-  const funcs = {};
+function getFuncDefs(graphiteVersion: string, idx?: any) {
+  const funcs: any = {};
   _.forEach(idx || index, funcDef => {
     if (isVersionRelatedFunction(funcDef, graphiteVersion)) {
       funcs[funcDef.name] = _.assign({}, funcDef, {
@@ -1079,8 +1090,8 @@ function getFuncDefs(graphiteVersion, idx?) {
 }
 
 // parse response from graphite /functions endpoint into internal format
-function parseFuncDefs(rawDefs) {
-  const funcDefs = {};
+function parseFuncDefs(rawDefs: any) {
+  const funcDefs: any = {};
 
   _.forEach(rawDefs || {}, (funcDef, funcName) => {
     // skip graphite graph functions
@@ -1097,9 +1108,9 @@ function parseFuncDefs(rawDefs) {
         .replace(/.. code-block *:: *none/g, '.. code-block::');
     }
 
-    const func = {
+    const func: FuncDef = {
       name: funcDef.name,
-      description: description,
+      description,
       category: funcDef.group,
       params: [],
       defaultParams: [],
@@ -1122,7 +1133,7 @@ function parseFuncDefs(rawDefs) {
     }
 
     _.forEach(funcDef.params, rawParam => {
-      const param = {
+      const param: any = {
         name: rawParam.name,
         type: 'string',
         optional: !rawParam.required,
