@@ -21,20 +21,23 @@ import { LocationUpdate, setLocationSrv } from '@grafana/runtime';
 import { updateLocation } from 'app/core/actions';
 
 // Types
-import { KioskUrlValue } from 'app/types';
+import { KioskUrlValue, CoreEvents, AppEventEmitter, AppEventConsumer } from 'app/types';
 import { setLinkSrv, LinkSrv } from 'app/features/panel/panellinks/link_srv';
 import { UtilSrv } from 'app/core/services/util_srv';
 import { ContextSrv } from 'app/core/services/context_srv';
 import { BridgeSrv } from 'app/core/services/bridge_srv';
 import { PlaylistSrv } from 'app/features/playlist/playlist_srv';
-import { ILocationService, ITimeoutService, IRootScopeService } from 'angular';
+import { ILocationService, ITimeoutService, IRootScopeService, IAngularEvent } from 'angular';
+import { AppEvent, AppEvents } from '@grafana/data';
+
+export type GrafanaRootScope = IRootScopeService & AppEventEmitter & AppEventConsumer & { colors: string[] };
 
 export class GrafanaCtrl {
   /** @ngInject */
   constructor(
     $scope: any,
     utilSrv: UtilSrv,
-    $rootScope: any,
+    $rootScope: GrafanaRootScope,
     contextSrv: ContextSrv,
     bridgeSrv: BridgeSrv,
     backendSrv: BackendSrv,
@@ -70,8 +73,18 @@ export class GrafanaCtrl {
 
     $rootScope.colors = colors;
 
-    $rootScope.onAppEvent = function(name: string, callback: () => void, localScope: any) {
-      const unbind = $rootScope.$on(name, callback);
+    $rootScope.onAppEvent = function<T>(
+      event: AppEvent<T> | string,
+      callback: (event: IAngularEvent, ...args: any[]) => void,
+      localScope?: any
+    ) {
+      let unbind;
+      if (typeof event === 'string') {
+        unbind = $rootScope.$on(event, callback);
+      } else {
+        unbind = $rootScope.$on(event.name, callback);
+      }
+
       let callerScope = this;
       if (callerScope.$id === 1 && !localScope) {
         console.log('warning rootScope onAppEvent called without localscope');
@@ -82,9 +95,14 @@ export class GrafanaCtrl {
       callerScope.$on('$destroy', unbind);
     };
 
-    $rootScope.appEvent = (name: string, payload: any) => {
-      $rootScope.$emit(name, payload);
-      appEvents.emit(name, payload);
+    $rootScope.appEvent = <T>(event: AppEvent<T> | string, payload?: T | any) => {
+      if (typeof event === 'string') {
+        $rootScope.$emit(event, payload);
+        appEvents.emit(event, payload);
+      } else {
+        $rootScope.$emit(event.name, payload);
+        appEvents.emit(event, payload);
+      }
     };
 
     $scope.init();
@@ -121,7 +139,7 @@ export function grafanaAppDirective(
   return {
     restrict: 'E',
     controller: GrafanaCtrl,
-    link: (scope: any, elem: JQuery) => {
+    link: (scope: IRootScopeService & AppEventEmitter, elem: JQuery) => {
       const body = $('body');
 
       // see https://github.com/zenorocha/clipboard.js/issues/155
@@ -129,19 +147,19 @@ export function grafanaAppDirective(
 
       $('.preloader').remove();
 
-      appEvents.on('toggle-sidemenu-mobile', () => {
+      appEvents.on(CoreEvents.toggleSidemenuMobile, () => {
         body.toggleClass('sidemenu-open--xs');
       });
 
-      appEvents.on('toggle-sidemenu-hidden', () => {
+      appEvents.on(CoreEvents.toggleSidemenuHidden, () => {
         body.toggleClass('sidemenu-hidden');
       });
 
-      appEvents.on('playlist-started', () => {
+      appEvents.on(CoreEvents.playlistStarted, () => {
         elem.toggleClass('view-mode--playlist', true);
       });
 
-      appEvents.on('playlist-stopped', () => {
+      appEvents.on(CoreEvents.playlistStopped, () => {
         elem.toggleClass('view-mode--playlist', false);
       });
 
@@ -178,11 +196,11 @@ export function grafanaAppDirective(
           drop.destroy();
         }
 
-        appEvents.emit('hide-dash-search');
+        appEvents.emit(CoreEvents.hideDashSearch);
       });
 
       // handle kiosk mode
-      appEvents.on('toggle-kiosk-mode', (options: { exit?: boolean }) => {
+      appEvents.on(CoreEvents.toggleKioskMode, (options: { exit?: boolean }) => {
         const search: { kiosk?: KioskUrlValue } = $location.search();
 
         if (options && options.exit) {
@@ -192,7 +210,7 @@ export function grafanaAppDirective(
         switch (search.kiosk) {
           case 'tv': {
             search.kiosk = true;
-            appEvents.emit('alert-success', ['Press ESC to exit Kiosk mode']);
+            appEvents.emit(AppEvents.alertSuccess, ['Press ESC to exit Kiosk mode']);
             break;
           }
           case '1':
@@ -248,7 +266,7 @@ export function grafanaAppDirective(
       // check every 2 seconds
       setInterval(checkForInActiveUser, 2000);
 
-      appEvents.on('toggle-view-mode', () => {
+      appEvents.on(CoreEvents.toggleViewMode, () => {
         lastActivity = 0;
         checkForInActiveUser();
       });
@@ -278,7 +296,7 @@ export function grafanaAppDirective(
         if (body.find('.search-container').length > 0) {
           if (target.parents('.search-results-container, .search-field-wrapper').length === 0) {
             scope.$apply(() => {
-              scope.appEvent('hide-dash-search');
+              scope.appEvent(CoreEvents.hideDashSearch);
             });
           }
         }
